@@ -29,19 +29,32 @@
 #include "KipiInterface/KSGKipiInterface.h"
 #endif
 
+#ifdef PURPOSE_FOUND
+#include <Purpose/AlternativesModel>
+#include <PurposeWidgets/Menu>
+#endif
+
 class ExportMenu : public QMenu
 {
+    Q_OBJECT
+
     public:
 
     explicit ExportMenu(QWidget *parent = 0);
+    void imageUpdated();
 
     private slots:
 
     void populateMenu();
 
+    signals:
+
+    void imageShared(bool error, const QString &message);
+
     private:
 
     void getKServiceItems();
+
 #ifdef KIPI_FOUND
     void getKipiItems();
     void loadKipiItems();
@@ -52,6 +65,14 @@ class ExportMenu : public QMenu
     QWidget mDummyWidget;
 #endif
 
+#ifdef PURPOSE_FOUND
+    void loadPurposeMenu();
+    void loadPurposeItems();
+
+    bool mUpdatedImageAvailable;
+    Purpose::Menu *mPurposeMenu;
+#endif
+
     ExportManager *mExportManager;
 };
 
