@@ -39,6 +39,7 @@
 #include <KStandardGuiItem>
 #include <KHelpMenu>
 #include <KAboutData>
+#include <KWindowSystem>
 
 #include "SettingsDialog/SettingsDialog.h"
 #include "ExportMenu.h"
@@ -67,7 +68,7 @@ KSMainWindow::KSMainWindow(bool onClickAvailable, QWidget *parent) :
     // credits for this goes to Thomas Lübking <thomas.luebking@gmail.com>
 
 #ifdef XCB_FOUND
-    if (qApp->platformName() == QStringLiteral("xcb")) {
+    if (KWindowSystem::isPlatformX11()) {
         // create a window if we haven't already. note that the QWidget constructor
         // should already have done this
 
@@ -106,10 +107,7 @@ void KSMainWindow::init()
     KConfigGroup guiConfig(config, "GuiConfig");
 
     // window properties
-
-    setMinimumSize(840, 420);
     setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
-    resize(minimumSize());
 
     QPoint location = guiConfig.readEntry("window-position", QPoint(50, 50));
     move(location);
@@ -178,6 +176,8 @@ void KSMainWindow::init()
     if (!mOnClickAvailable) {
         mKSWidget->disableOnClick();
     }
+    resize(QSize(840, 420).expandedTo(minimumSize()));
+
 
     // done with the init
 }
@@ -250,7 +250,7 @@ void KSMainWindow::captureScreenshot(ImageGrabber::GrabMode mode, int timeout, b
 void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap)
 {
     mKSWidget->setScreenshotPixmap(pixmap);
-    mExportMenu->imageUpdated(ExportManager::instance()->pixmapDataUri());
+    mExportMenu->imageUpdated();
 
     setWindowTitle(i18nc("Unsaved Screenshot", "Unsaved[*]"));
     setWindowModified(true);
@@ -278,7 +278,10 @@ void KSMainWindow::showImageSharedFeedback(bool error, const QString &message)
         mMessageWidget->setIcon(QIcon::fromTheme(QStringLiteral("dialog-error")));
     } else {
         mMessageWidget->setMessageType(KMessageWidget::Positive);
-        mMessageWidget->setText(i18n("You can find the shared image at: <a href=\"%1\">%1</a>", message));
+        if (message.isEmpty())
+            mMessageWidget->setText(i18n("Image shared"));
+        else
+            mMessageWidget->setText(i18n("You can find the shared image at: <a href=\"%1\">%1</a>", message));
         mMessageWidget->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")));
     }
 
