@@ -29,6 +29,7 @@
 #include <KMessageWidget>
 
 #include "PlatformBackends/ImageGrabber.h"
+#include "ExportMenu.h"
 #include "KSWidget.h"
 
 class KSMainWindow : public QDialog
@@ -44,9 +45,11 @@ class KSMainWindow : public QDialog
 
     void captureScreenshot(ImageGrabber::GrabMode mode, int timeout, bool includePointer, bool includeDecorations);
     void showPrintDialog();
-    void showSaveConfigDialog();
+    void showPreferencesDialog();
+    void showImageSharedFeedback(bool error, const QString &message);
     void sendToClipboard();
     void init();
+    void buildSaveMenu();
     void save();
     void saveAs();
     void saveAndExit();
@@ -63,7 +66,7 @@ class KSMainWindow : public QDialog
 
     protected:
 
-    void moveEvent(QMoveEvent *event);
+    void moveEvent(QMoveEvent *event) Q_DECL_OVERRIDE;
 
     private:
 
@@ -74,8 +77,8 @@ class KSMainWindow : public QDialog
     QToolButton      *mClipboardButton;
     QToolButton      *mSaveButton;
     QMenu            *mSaveMenu;
-    KMessageWidget   *mCopyMessage;
-    QMenu            *mExportMenu;
+    KMessageWidget   *mMessageWidget;
+    ExportMenu       *mExportMenu;
     bool              mOnClickAvailable;
 };
 
