@@ -31,6 +31,7 @@
 
 #include "SpectacleCore.h"
 #include "SpectacleDBusAdapter.h"
+#include "ExportManager.h"
 #include "Config.h"
 
 int main(int argc, char **argv)
@@ -39,25 +40,21 @@ int main(int argc, char **argv)
 
     QApplication app(argc, argv);
 
-    app.setOrganizationDomain("kde.org");
-    app.setApplicationName("spectacle");
-    app.setWindowIcon(QIcon::fromTheme("spectacle"));
-
     app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
-    // set up the about data
-
     KLocalizedString::setApplicationDomain("spectacle");
+
     KAboutData aboutData("spectacle",
                          i18n("Spectacle"),
-                         SPECTACLE_VERSION,
+                         QStringLiteral(SPECTACLE_VERSION) + QStringLiteral(" - ") + QStringLiteral(SPECTACLE_CODENAME),
                          i18n("KDE Screenshot Utility"),
                          KAboutLicense::GPL_V2,
                          i18n("(C) 2015 Boudhayan Gupta"));
     aboutData.addAuthor("Boudhayan Gupta", QString(), "bgupta@kde.org");
     aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     KAboutData::setApplicationData(aboutData);
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("spectacle")));
 
     // set up the command line options parser
 
@@ -150,8 +147,10 @@ int main(int argc, char **argv)
     new KDBusService(KDBusService::Multiple, &core);
 
     SpectacleDBusAdapter *dbusAdapter = new SpectacleDBusAdapter(&core);
-    QObject::connect(&core, &SpectacleCore::imageSaved, dbusAdapter, &SpectacleDBusAdapter::ScreenshotTaken);
     QObject::connect(&core, &SpectacleCore::grabFailed, dbusAdapter, &SpectacleDBusAdapter::ScreenshotFailed);
+    QObject::connect(ExportManager::instance(), &ExportManager::imageSaved, [&](const QUrl savedAt) {
+        emit dbusAdapter->ScreenshotTaken(savedAt.toLocalFile());
+    });
 
     QDBusConnection::sessionBus().registerObject("/", &core);
     QDBusConnection::sessionBus().registerService("org.kde.Spectacle");
