@@ -28,18 +28,13 @@
 #include "ImageGrabber.h"
 
 class X11ImageGrabber;
-namespace KScreen
-{
-    class GetConfigOperation;
-    class ConfigOperation;
-}
 
 class OnClickEventFilter : public QAbstractNativeEventFilter
 {
     public:
 
     explicit OnClickEventFilter(X11ImageGrabber *grabber);
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result);
+    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) Q_DECL_OVERRIDE;
 
     private:
 
@@ -70,7 +65,6 @@ class X11ImageGrabber : public ImageGrabber
     private slots:
 
     void KWinDBusScreenshotHelper(quint64 window);
-    void KScreenCurrentMonitorScreenshotHelper(KScreen::ConfigOperation *op);
     void rectangleSelectionConfirmed(const QPixmap &pixmap, const QRect &region);
     void rectangleSelectionCancelled();
 
@@ -83,16 +77,27 @@ class X11ImageGrabber : public ImageGrabber
     bool                 isKWinAvailable();
     xcb_window_t         getRealWindowUnderCursor();
     void                 grabApplicationWindowHelper(xcb_window_t window);
-    QRect                getApplicationWindowGeometry(xcb_window_t window);
-    QStack<xcb_window_t> findAllChildren(xcb_window_t window);
-    xcb_window_t         findParent(xcb_window_t window);
+    QRect                getDrawableGeometry(xcb_drawable_t drawable);
+    QPixmap              postProcessPixmap(QPixmap pixmap, QRect rect, bool blendPointer);
+    QPixmap              getPixmapFromDrawable(xcb_drawable_t drawableId, const QRect &rect);
+    QPixmap              getToplevelPixmap(QRect rect, bool blendPointer);
     QPixmap              getWindowPixmap(xcb_window_t window, bool blendPointer);
     QPixmap              convertFromNative(xcb_image_t *xcbImage);
+    xcb_window_t         getTransientWindowParent(xcb_window_t winId, QRect &outRect);
+    QPoint               getNativeCursorPosition();
 
     OnClickEventFilter          *mNativeEventFilter;
-    KScreen::GetConfigOperation *mScreenConfigOperation;
 };
 
 template <typename T> using CScopedPointer = QScopedPointer<T, QScopedPointerPodDeleter>;
 
+struct ScopedPointerXcbImageDeleter
+{
+    static inline void cleanup(xcb_image_t *xcbImage) {
+        if (xcbImage) {
+            xcb_image_destroy(xcbImage);
+        }
+    }
+};
+
 #endif // X11IMAGEGRABBER_H
